@@ -9,6 +9,7 @@
 #  See the file README for copying conditions.
 #
 
+from werkzeug.wrappers import BaseResponse
 from glashammer.utils import render_response, Response
 from glashammer.utils.appliance import Appliance
 
@@ -36,7 +37,7 @@ def render_to(template):
     def _outer(view):
         def _inner(*args, **kwargs):
             result = view(*args, **kwargs)
-            if isinstance(result, Response):
+            if isinstance(result, (Response, BaseResponse)):
                 return result
             assert isinstance(result, dict), ('view decorated by render_to must '
                                               'return a dictionary')
